package com.ruoyi.custclient.mapper;

import java.util.List;
import com.ruoyi.custclient.domain.VehiclePhoto;

/**
 * 车辆影像化资料Mapper接口
 * 
 * @author wuyufei
 * @date 2024-10-21
 */
public interface VehiclePhotoMapper 
{
    /**
     * 查询车辆影像化资料
     * 
     * @param id 车辆影像化资料主键
     * @return 车辆影像化资料
     */
    public VehiclePhoto selectVehiclePhotoById(Long id);

    /**
     * 查询车辆影像化资料列表
     * 
     * @param vehiclePhoto 车辆影像化资料
     * @return 车辆影像化资料集合
     */
    public List<VehiclePhoto> selectVehiclePhotoList(VehiclePhoto vehiclePhoto);

    /**
     * 新增车辆影像化资料
     * 
     * @param vehiclePhoto 车辆影像化资料
     * @return 结果
     */
    public int insertVehiclePhoto(VehiclePhoto vehiclePhoto);

    /**
     * 修改车辆影像化资料
     * 
     * @param vehiclePhoto 车辆影像化资料
     * @return 结果
     */
    public int updateVehiclePhoto(VehiclePhoto vehiclePhoto);

    /**
     * 删除车辆影像化资料
     * 
     * @param id 车辆影像化资料主键
     * @return 结果
     */
    public int deleteVehiclePhotoById(Long id);

    /**
     * 批量删除车辆影像化资料
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteVehiclePhotoByIds(Long[] ids);
}
